@@ -6,8 +6,11 @@ from pathlib import Path
 def read_configuration(filename: PathLike) -> {str: str}:
     configuration_file = configparser.ConfigParser()
     configuration_file.read(filename)
-    return {section_name: {key: value for key, value in section.items()}
-            for section_name, section in configuration_file.items() if section_name.upper() != 'DEFAULT'}
+    return {
+        section_name: {key: value for key, value in section.items()}
+        for section_name, section in configuration_file.items()
+        if section_name.upper() != 'DEFAULT'
+    }
 
 
 def repository_root(path: PathLike = None) -> Path:
